reset mechanisms
----------------
.. currentmodule:: sinabs.activation
    
MembraneReset
^^^^^^^^^^^^^
.. autoclass:: MembraneReset
    :members:

MembraneSubtract
^^^^^^^^^^^^^^^^
.. autoclass:: MembraneSubtract
    :members:
